@@ -6,7 +6,5 @@
 #' @author \strong{Conceptual design by:} Mijael Rodrigo Vargas Godoy \email{vargas_godoy@fzp.czu.cz} and Yannis Markonis \email{markonis@fzp.czu.cz}
 #' 
 #' @references Vargas Godoy, M. R., & Markonis, Y. (2023). pRecipe: A global precipitation climatology toolbox and database. Environmental Modelling & Software, 165, 105711. \doi{10.1016/j.envsoft.2023.105711}
-#' @docType package
-#' @name pRecipe-package
-NULL
-#> NULL
\ No newline at end of file
+#' @keywords internal 
+"_PACKAGE"
\ No newline at end of file
